@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,30 +18,26 @@ package com.google.inject.internal;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 
-import com.google.common.base.Optional;
 import com.google.common.collect.HashMultimap;
+import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Multimap;
 import com.google.inject.Binder;
 import com.google.inject.Key;
 import com.google.inject.Module;
-import com.google.inject.Provider;
 import com.google.inject.Provides;
 import com.google.inject.TypeLiteral;
-import com.google.inject.spi.Dependency;
 import com.google.inject.spi.InjectionPoint;
 import com.google.inject.spi.Message;
 import com.google.inject.spi.ModuleAnnotatedMethodScanner;
 import com.google.inject.util.Modules;
-
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Member;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.util.Arrays;
 import java.util.List;
-import java.util.Set;
 
 /**
  * Creates bindings to methods annotated with {@literal @}{@link Provides}. Use the scope and
@@ -51,61 +47,42 @@ import java.util.Set;
  * @author jessewilson@google.com (Jesse Wilson)
  */
 public final class ProviderMethodsModule implements Module {
-
-  private static ModuleAnnotatedMethodScanner PROVIDES_BUILDER =
-      new ModuleAnnotatedMethodScanner() {
-        @Override
-        public <T> Key<T> prepareMethod(
-            Binder binder, Annotation annotation, Key<T> key, InjectionPoint injectionPoint) {
-          return key;
-        }
-
-        @Override
-        public Set<? extends Class<? extends Annotation>> annotationClasses() {
-          return ImmutableSet.of(Provides.class);
-        }
-      };
-
   private final Object delegate;
   private final TypeLiteral<?> typeLiteral;
   private final boolean skipFastClassGeneration;
   private final ModuleAnnotatedMethodScanner scanner;
 
-  private ProviderMethodsModule(Object delegate, boolean skipFastClassGeneration,
-      ModuleAnnotatedMethodScanner scanner) {
+  private ProviderMethodsModule(
+      Object delegate, boolean skipFastClassGeneration, ModuleAnnotatedMethodScanner scanner) {
     this.delegate = checkNotNull(delegate, "delegate");
     this.typeLiteral = TypeLiteral.get(this.delegate.getClass());
     this.skipFastClassGeneration = skipFastClassGeneration;
     this.scanner = scanner;
   }
 
-  /**
-   * Returns a module which creates bindings for provider methods from the given module.
-   */
+  /** Returns a module which creates bindings for provider methods from the given module. */
   public static Module forModule(Module module) {
-    return forObject(module, false, PROVIDES_BUILDER);
+    return forObject(module, false, ProvidesMethodScanner.INSTANCE);
   }
 
-  /**
-   * Returns a module which creates bindings methods in the module that match the scanner.
-   */
+  /** Returns a module which creates bindings methods in the module that match the scanner. */
   public static Module forModule(Object module, ModuleAnnotatedMethodScanner scanner) {
     return forObject(module, false, scanner);
   }
 
   /**
-   * Returns a module which creates bindings for provider methods from the given object.
-   * This is useful notably for <a href="http://code.google.com/p/google-gin/">GIN</a>
+   * Returns a module which creates bindings for provider methods from the given object. This is
+   * useful notably for <a href="http://code.google.com/p/google-gin/">GIN</a>
    *
    * <p>This will skip bytecode generation for provider methods, since it is assumed that callers
    * are only interested in Module metadata.
    */
   public static Module forObject(Object object) {
-    return forObject(object, true, PROVIDES_BUILDER);
+    return forObject(object, true, ProvidesMethodScanner.INSTANCE);
   }
 
-  private static Module forObject(Object object, boolean skipFastClassGeneration,
-      ModuleAnnotatedMethodScanner scanner) {
+  private static Module forObject(
+      Object object, boolean skipFastClassGeneration, ModuleAnnotatedMethodScanner scanner) {
     // avoid infinite recursion, since installing a module always installs itself
     if (object instanceof ProviderMethodsModule) {
       return Modules.EMPTY_MODULE;
@@ -119,91 +96,115 @@ public final class ProviderMethodsModule implements Module {
   }
 
   @Override
-  public synchronized void configure(Binder binder) {
+  public void configure(Binder binder) {
     for (ProviderMethod<?> providerMethod : getProviderMethods(binder)) {
       providerMethod.configure(binder);
     }
   }
 
   public List<ProviderMethod<?>> getProviderMethods(Binder binder) {
-    List<ProviderMethod<?>> result = Lists.newArrayList();
-    Multimap<Signature, Method> methodsBySignature = HashMultimap.create();
+    List<ProviderMethod<?>> result = null;
+    // The highest class in the type hierarchy that contained a provider method definition.
+    Class<?> superMostClass = delegate.getClass();
     for (Class<?> c = delegate.getClass(); c != Object.class; c = c.getSuperclass()) {
       for (Method method : c.getDeclaredMethods()) {
-        // private/static methods cannot override or be overridden by other methods, so there is no
-        // point in indexing them.
-        // Skip synthetic methods and bridge methods since java will automatically generate
-        // synthetic overrides in some cases where we don't want to generate an error (e.g.
-        // increasing visibility of a subclass).
-        if (((method.getModifiers() & (Modifier.PRIVATE | Modifier.STATIC)) == 0)
-            && !method.isBridge() && !method.isSynthetic()) {
-          methodsBySignature.put(new Signature(method), method);
-        }
-        Optional<Annotation> annotation = isProvider(binder, method);
-        if (annotation.isPresent()) {
-          result.add(createProviderMethod(binder, method, annotation.get()));
+        Annotation annotation = getAnnotation(binder, method);
+        if (annotation != null) {
+          if (result == null) {
+            result = Lists.newArrayList();
+          }
+          result.add(createProviderMethod(binder, method, annotation));
+          superMostClass = c;
         }
       }
     }
-    // we have found all the providers and now need to identify if any were overridden
-    // In the worst case this will have O(n^2) in the number of @Provides methods, but that is only
-    // assuming that every method is an override, in general it should be very quick.
-    for (ProviderMethod<?> provider : result) {
-      Method method = provider.getMethod();
-      for (Method matchingSignature : methodsBySignature.get(new Signature(method))) {
-        // matching signature is in the same class or a super class, therefore method cannot be
-        // overridding it.
-        if (matchingSignature.getDeclaringClass().isAssignableFrom(method.getDeclaringClass())) {
-          continue;
+    if (result == null) {
+      // We didn't find anything
+      return ImmutableList.of();
+    }
+    // We have found some provider methods, now we need to check if any were overridden.
+    // We do this as a separate pass to avoid calculating all the signatures when there are no
+    // provides methods, or when all provides methods are defined in a single class.
+    Multimap<Signature, Method> methodsBySignature = null;
+    // We can stop scanning when we see superMostClass, since no superclass method can override
+    // a method in a subclass.  Corrollary, if superMostClass == delegate.getClass(), there can be
+    // no overrides of a provides method.
+    for (Class<?> c = delegate.getClass(); c != superMostClass; c = c.getSuperclass()) {
+      for (Method method : c.getDeclaredMethods()) {
+        if (((method.getModifiers() & (Modifier.PRIVATE | Modifier.STATIC)) == 0)
+            && !method.isBridge()
+            && !method.isSynthetic()) {
+          if (methodsBySignature == null) {
+            methodsBySignature = HashMultimap.create();
+          }
+          methodsBySignature.put(new Signature(typeLiteral, method), method);
         }
-        // now we know matching signature is in a subtype of method.getDeclaringClass()
-        if (overrides(matchingSignature, method)) {
-          String annotationString = provider.getAnnotation().annotationType() == Provides.class
-              ? "@Provides" : "@" + provider.getAnnotation().annotationType().getCanonicalName();
-          binder.addError(
-              "Overriding " + annotationString + " methods is not allowed."
-                  + "\n\t" + annotationString + " method: %s\n\toverridden by: %s",
-              method,
-              matchingSignature);
-          break;
+      }
+    }
+    if (methodsBySignature != null) {
+      // we have found all the signatures and now need to identify if any were overridden
+      // In the worst case this will have O(n^2) in the number of @Provides methods, but that is
+      // only assuming that every method is an override, in general it should be very quick.
+      for (ProviderMethod<?> provider : result) {
+        Method method = provider.getMethod();
+        for (Method matchingSignature :
+            methodsBySignature.get(new Signature(typeLiteral, method))) {
+          // matching signature is in the same class or a super class, therefore method cannot be
+          // overridding it.
+          if (matchingSignature.getDeclaringClass().isAssignableFrom(method.getDeclaringClass())) {
+            continue;
+          }
+          // now we know matching signature is in a subtype of method.getDeclaringClass()
+          if (overrides(matchingSignature, method)) {
+            String annotationString =
+                provider.getAnnotation().annotationType() == Provides.class
+                    ? "@Provides"
+                    : "@" + provider.getAnnotation().annotationType().getCanonicalName();
+            binder.addError(
+                "Overriding "
+                    + annotationString
+                    + " methods is not allowed."
+                    + "\n\t"
+                    + annotationString
+                    + " method: %s\n\toverridden by: %s",
+                method,
+                matchingSignature);
+            break;
+          }
         }
       }
     }
     return result;
   }
 
-  /**
-   * Returns true if the method is a provider.
-   *
-   * Synthetic bridge methods are excluded. Starting with JDK 8, javac copies annotations onto
-   * bridge methods (which always have erased signatures).
-   */
-  private Optional<Annotation> isProvider(Binder binder, Method method) {
+  /** Returns the annotation that is claimed by the scanner, or null if there is none. */
+  private Annotation getAnnotation(Binder binder, Method method) {
     if (method.isBridge() || method.isSynthetic()) {
-      return Optional.absent();
+      return null;
     }
     Annotation annotation = null;
     for (Class<? extends Annotation> annotationClass : scanner.annotationClasses()) {
       Annotation foundAnnotation = method.getAnnotation(annotationClass);
       if (foundAnnotation != null) {
         if (annotation != null) {
-          binder.addError("More than one annotation claimed by %s on method %s."
-              + " Methods can only have one annotation claimed per scanner.",
+          binder.addError(
+              "More than one annotation claimed by %s on method %s."
+                  + " Methods can only have one annotation claimed per scanner.",
               scanner, method);
-          return Optional.absent();
+          return null;
         }
         annotation = foundAnnotation;
       }
     }
-    return Optional.fromNullable(annotation);
+    return annotation;
   }
 
-  private final class Signature {
+  private static final class Signature {
     final Class<?>[] parameters;
     final String name;
     final int hashCode;
 
-    Signature(Method method) {
+    Signature(TypeLiteral<?> typeLiteral, Method method) {
       this.name = method.getName();
       // We need to 'resolve' the parameters against the actual class type in case this method uses
       // type parameters.  This is so we can detect overrides of generic superclass methods where
@@ -219,7 +220,8 @@ public final class ProviderMethodsModule implements Module {
       this.hashCode = name.hashCode() + 31 * Arrays.hashCode(parameters);
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(Object obj) {
       if (obj instanceof Signature) {
         Signature other = (Signature) obj;
         return other.name.equals(name) && Arrays.equals(parameters, other.parameters);
@@ -227,7 +229,8 @@ public final class ProviderMethodsModule implements Module {
       return false;
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return hashCode;
     }
   }
@@ -246,34 +249,34 @@ public final class ProviderMethodsModule implements Module {
     return a.getDeclaringClass().getPackage().equals(b.getDeclaringClass().getPackage());
   }
 
-  private <T> ProviderMethod<T> createProviderMethod(Binder binder, Method method,
-      Annotation annotation) {
+  private <T> ProviderMethod<T> createProviderMethod(
+      Binder binder, Method method, Annotation annotation) {
     binder = binder.withSource(method);
     Errors errors = new Errors(method);
 
     // prepare the parameter providers
     InjectionPoint point = InjectionPoint.forMethod(method, typeLiteral);
-    List<Dependency<?>> dependencies = point.getDependencies();
-    List<Provider<?>> parameterProviders = Lists.newArrayList();
-    for (Dependency<?> dependency : point.getDependencies()) {
-      parameterProviders.add(binder.getProvider(dependency));
-    }
-
     @SuppressWarnings("unchecked") // Define T as the method's return type.
     TypeLiteral<T> returnType = (TypeLiteral<T>) typeLiteral.getReturnType(method);
     Key<T> key = getKey(errors, returnType, method, method.getAnnotations());
     try {
       key = scanner.prepareMethod(binder, annotation, key, point);
-    } catch(Throwable t) {
+    } catch (Throwable t) {
       binder.addError(t);
     }
-    Class<? extends Annotation> scopeAnnotation
-        = Annotations.findScopeAnnotation(errors, method.getAnnotations());
+    Class<? extends Annotation> scopeAnnotation =
+        Annotations.findScopeAnnotation(errors, method.getAnnotations());
     for (Message message : errors.getMessages()) {
       binder.addError(message);
     }
-    return ProviderMethod.create(key, method, delegate, ImmutableSet.copyOf(dependencies),
-        parameterProviders, scopeAnnotation, skipFastClassGeneration, annotation);
+    return ProviderMethod.create(
+        key,
+        method,
+        delegate,
+        ImmutableSet.copyOf(point.getDependencies()),
+        scopeAnnotation,
+        skipFastClassGeneration,
+        annotation);
   }
 
   <T> Key<T> getKey(Errors errors, TypeLiteral<T> type, Member member, Annotation[] annotations) {
@@ -281,13 +284,15 @@ public final class ProviderMethodsModule implements Module {
     return bindingAnnotation == null ? Key.get(type) : Key.get(type, bindingAnnotation);
   }
 
-  @Override public boolean equals(Object o) {
+  @Override
+  public boolean equals(Object o) {
     return o instanceof ProviderMethodsModule
         && ((ProviderMethodsModule) o).delegate == delegate
         && ((ProviderMethodsModule) o).scanner == scanner;
   }
 
-  @Override public int hashCode() {
+  @Override
+  public int hashCode() {
     return delegate.hashCode();
   }
 }
