@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,6 +19,7 @@ package com.google.inject.assistedinject;
 import static com.google.common.base.Preconditions.checkState;
 import static com.google.common.collect.Iterables.getOnlyElement;
 
+import com.google.common.base.MoreObjects;
 import com.google.common.base.Objects;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.ImmutableList;
@@ -55,7 +56,6 @@ import com.google.inject.spi.ProviderInstanceBinding;
 import com.google.inject.spi.ProviderWithExtensionVisitor;
 import com.google.inject.spi.Toolable;
 import com.google.inject.util.Providers;
-
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationHandler;
@@ -74,16 +74,19 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 
 /**
- * The newer implementation of factory provider. This implementation uses a child injector to
- * create values.
+ * The newer implementation of factory provider. This implementation uses a child injector to create
+ * values.
  *
  * @author jessewilson@google.com (Jesse Wilson)
  * @author dtm@google.com (Daniel Martin)
  * @author schmitt@google.com (Peter Schmitt)
  * @author sameb@google.com (Sam Berlin)
  */
-final class FactoryProvider2 <F> implements InvocationHandler,
-    ProviderWithExtensionVisitor<F>, HasDependencies, AssistedInjectBinding<F> {
+final class FactoryProvider2<F>
+    implements InvocationHandler,
+        ProviderWithExtensionVisitor<F>,
+        HasDependencies,
+        AssistedInjectBinding<F> {
 
   /** A constant annotation to denote the return value, instead of creating a new one each time. */
   static final Annotation RETURN_ANNOTATION = UniqueAnnotations.create();
@@ -92,27 +95,37 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   static final Logger logger = Logger.getLogger(AssistedInject.class.getName());
 
   /** if a factory method parameter isn't annotated, it gets this annotation. */
-  static final Assisted DEFAULT_ANNOTATION = new Assisted() {
-    public String value() {
-      return "";
-    }
+  static final Assisted DEFAULT_ANNOTATION =
+      new Assisted() {
+        @Override
+        public String value() {
+          return "";
+        }
 
-    public Class<? extends Annotation> annotationType() {
-      return Assisted.class;
-    }
+        @Override
+        public Class<? extends Annotation> annotationType() {
+          return Assisted.class;
+        }
 
-    @Override public boolean equals(Object o) {
-      return o instanceof Assisted && ((Assisted) o).value().isEmpty();
-    }
+        @Override
+        public boolean equals(Object o) {
+          return o instanceof Assisted && ((Assisted) o).value().isEmpty();
+        }
 
-    @Override public int hashCode() {
-      return 127 * "value".hashCode() ^ "".hashCode();
-    }
+        @Override
+        public int hashCode() {
+          return 127 * "value".hashCode() ^ "".hashCode();
+        }
 
-    @Override public String toString() {
-      return "@" + Assisted.class.getName() + "(value=)";
-    }
-  };
+        @Override
+        public String toString() {
+          return "@"
+              + Assisted.class.getName()
+              + "(value="
+              + Annotations.memberValueString("")
+              + ")";
+        }
+      };
 
   /** All the data necessary to perform an assisted inject. */
   private static class AssistData implements AssistedMethod {
@@ -127,7 +140,7 @@ final class FactoryProvider2 <F> implements InvocationHandler,
 
     /** All non-assisted dependencies required by this method. */
     final Set<Dependency<?>> dependencies;
-    /** The factory method associated with this data*/
+    /** The factory method associated with this data */
     final Method factoryMethod;
 
     /** true if {@link #isValidForOptimizedAssistedInject} returned true. */
@@ -137,10 +150,15 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     /** used to perform optimized factory creations. */
     volatile Binding<?> cachedBinding; // TODO: volatile necessary?
 
-    AssistData(Constructor<?> constructor, Key<?> returnType, ImmutableList<Key<?>> paramTypes,
-        TypeLiteral<?> implementationType, Method factoryMethod,
+    AssistData(
+        Constructor<?> constructor,
+        Key<?> returnType,
+        ImmutableList<Key<?>> paramTypes,
+        TypeLiteral<?> implementationType,
+        Method factoryMethod,
         Set<Dependency<?>> dependencies,
-        boolean optimized, List<ThreadLocalProvider> providers) {
+        boolean optimized,
+        List<ThreadLocalProvider> providers) {
       this.constructor = constructor;
       this.returnType = returnType;
       this.paramTypes = paramTypes;
@@ -153,31 +171,35 @@ final class FactoryProvider2 <F> implements InvocationHandler,
 
     @Override
     public String toString() {
-      return Objects.toStringHelper(getClass())
-        .add("ctor", constructor)
-        .add("return type", returnType)
-        .add("param type", paramTypes)
-        .add("implementation type", implementationType)
-        .add("dependencies", dependencies)
-        .add("factory method", factoryMethod)
-        .add("optimized", optimized)
-        .add("providers", providers)
-        .add("cached binding", cachedBinding)
-        .toString();
+      return MoreObjects.toStringHelper(getClass())
+          .add("ctor", constructor)
+          .add("return type", returnType)
+          .add("param type", paramTypes)
+          .add("implementation type", implementationType)
+          .add("dependencies", dependencies)
+          .add("factory method", factoryMethod)
+          .add("optimized", optimized)
+          .add("providers", providers)
+          .add("cached binding", cachedBinding)
+          .toString();
     }
 
+    @Override
     public Set<Dependency<?>> getDependencies() {
       return dependencies;
     }
 
+    @Override
     public Method getFactoryMethod() {
       return factoryMethod;
     }
 
+    @Override
     public Constructor<?> getImplementationConstructor() {
       return constructor;
     }
 
+    @Override
     public TypeLiteral<?> getImplementationType() {
       return implementationType;
     }
@@ -194,17 +216,16 @@ final class FactoryProvider2 <F> implements InvocationHandler,
 
   /** the factory interface, implemented and provided */
   private final F factory;
-  
+
   /** The key that this is bound to. */
   private final Key<F> factoryKey;
-  
+
   /** The binding collector, for equality/hashing purposes. */
   private final BindingCollector collector;
 
   /**
    * @param factoryKey a key for a Java interface that defines one or more create methods.
-   * @param collector binding configuration that maps method return types to
-   *    implementation types.
+   * @param collector binding configuration that maps method return types to implementation types.
    */
   FactoryProvider2(Key<F> factoryKey, BindingCollector collector) {
     this.factoryKey = factoryKey;
@@ -217,7 +238,7 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     Class<F> factoryRawType = (Class<F>) (Class<?>) factoryType.getRawType();
 
     try {
-      if(!factoryRawType.isInterface()) {
+      if (!factoryRawType.isInterface()) {
         throw errors.addMessage("%s must be an interface.", factoryRawType).toException();
       }
 
@@ -226,6 +247,11 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       ImmutableMap.Builder<Method, AssistData> assistDataBuilder = ImmutableMap.builder();
       // TODO: also grab methods from superinterfaces
       for (Method method : factoryRawType.getMethods()) {
+        // Skip static methods
+        if (Modifier.isStatic(method.getModifiers())) {
+          continue;
+        }
+
         // Skip default methods that java8 may have created.
         if (isDefault(method) && (method.isBridge() || method.isSynthetic())) {
           // Even synthetic default methods need the return type validation...
@@ -239,11 +265,12 @@ final class FactoryProvider2 <F> implements InvocationHandler,
         TypeLiteral<?> returnTypeLiteral = factoryType.getReturnType(method);
         Key<?> returnType;
         try {
-          returnType = Annotations.getKey(returnTypeLiteral, method, method.getAnnotations(), errors);
-        } catch(ConfigurationException ce) {
+          returnType =
+              Annotations.getKey(returnTypeLiteral, method, method.getAnnotations(), errors);
+        } catch (ConfigurationException ce) {
           // If this was an error due to returnTypeLiteral not being specified, rephrase
           // it as our factory not being specified, so it makes more sense to users.
-          if(isTypeNotSpecified(returnTypeLiteral, ce)) {
+          if (isTypeNotSpecified(returnTypeLiteral, ce)) {
             throw errors.keyNotFullySpecified(TypeLiteral.get(factoryRawType)).toException();
           } else {
             throw ce;
@@ -259,9 +286,10 @@ final class FactoryProvider2 <F> implements InvocationHandler,
           Class<?> underlylingType = paramKey.getTypeLiteral().getRawType();
           if (underlylingType.equals(Provider.class)
               || underlylingType.equals(javax.inject.Provider.class)) {
-            errors.addMessage("A Provider may not be a type in a factory method of an AssistedInject."
+            errors.addMessage(
+                "A Provider may not be a type in a factory method of an AssistedInject."
                     + "\n  Offending instance is parameter [%s] with key [%s] on method [%s]",
-                    p, paramKey, method);
+                p, paramKey, method);
           }
           keys.add(assistKey(method, paramKey, errors));
         }
@@ -269,23 +297,25 @@ final class FactoryProvider2 <F> implements InvocationHandler,
 
         // try to match up the method to the constructor
         TypeLiteral<?> implementation = collector.getBindings().get(returnType);
-        if(implementation == null) {
+        if (implementation == null) {
           implementation = returnType.getTypeLiteral();
         }
         Class<? extends Annotation> scope =
             Annotations.findScopeAnnotation(errors, implementation.getRawType());
         if (scope != null) {
-          errors.addMessage("Found scope annotation [%s] on implementation class "
-              + "[%s] of AssistedInject factory [%s].\nThis is not allowed, please"
-              + " remove the scope annotation.",
+          errors.addMessage(
+              "Found scope annotation [%s] on implementation class "
+                  + "[%s] of AssistedInject factory [%s].\nThis is not allowed, please"
+                  + " remove the scope annotation.",
               scope, implementation.getRawType(), factoryType);
         }
-        
+
         InjectionPoint ctorInjectionPoint;
         try {
           ctorInjectionPoint =
-            findMatchingConstructorInjectionPoint(method, returnType, implementation, immutableParamList);
-        } catch(ErrorsException ee) {
+              findMatchingConstructorInjectionPoint(
+                  method, returnType, implementation, immutableParamList);
+        } catch (ErrorsException ee) {
           errors.merge(ee.getErrors());
           continue;
         }
@@ -299,34 +329,41 @@ final class FactoryProvider2 <F> implements InvocationHandler,
         // all injections directly inject the object itself (and not a Provider of the object,
         // or an Injector), because it caches a single child injector and mutates the Provider
         // of the arguments in a ThreadLocal.
-        if(isValidForOptimizedAssistedInject(deps, implementation.getRawType(), factoryType)) {
+        if (isValidForOptimizedAssistedInject(deps, implementation.getRawType(), factoryType)) {
           ImmutableList.Builder<ThreadLocalProvider> providerListBuilder = ImmutableList.builder();
-          for(int i = 0; i < params.size(); i++) {
+          for (int i = 0; i < params.size(); i++) {
             providerListBuilder.add(new ThreadLocalProvider());
           }
           providers = providerListBuilder.build();
           optimized = true;
         }
 
-        AssistData data = new AssistData(constructor,
-            returnType,
-            immutableParamList,
-            implementation,
-            method,
-            removeAssistedDeps(deps),
-            optimized,
-            providers);
+        AssistData data =
+            new AssistData(
+                constructor,
+                returnType,
+                immutableParamList,
+                implementation,
+                method,
+                removeAssistedDeps(deps),
+                optimized,
+                providers);
         assistDataBuilder.put(method, data);
       }
 
-      factory = factoryRawType.cast(Proxy.newProxyInstance(
-          BytecodeGen.getClassLoader(factoryRawType), new Class<?>[] {factoryRawType}, this));
+      factory =
+          factoryRawType.cast(
+              Proxy.newProxyInstance(
+                  BytecodeGen.getClassLoader(factoryRawType),
+                  new Class<?>[] {factoryRawType},
+                  this));
 
       // Now go back through default methods. Try to use MethodHandles to make things
       // work.  If that doesn't work, fallback to trying to find compatible method
       // signatures.
       Map<Method, AssistData> dataSoFar = assistDataBuilder.build();
-      ImmutableMap.Builder<Method, MethodHandleWrapper> methodHandleBuilder = ImmutableMap.builder();
+      ImmutableMap.Builder<Method, MethodHandleWrapper> methodHandleBuilder =
+          ImmutableMap.builder();
       for (Map.Entry<String, Method> entry : defaultMethods.entries()) {
         Method defaultMethod = entry.getValue();
         MethodHandleWrapper handle = MethodHandleWrapper.create(defaultMethod, factory);
@@ -337,10 +374,11 @@ final class FactoryProvider2 <F> implements InvocationHandler,
           for (Method otherMethod : otherMethods.get(defaultMethod.getName())) {
             if (dataSoFar.containsKey(otherMethod) && isCompatible(defaultMethod, otherMethod)) {
               if (foundMatch) {
-                errors.addMessage("Generated default method %s with parameters %s is"
-                    + " signature-compatible with more than one non-default method."
-                    + " Unable to create factory. As a workaround, remove the override"
-                    + " so javac stops generating a default method.",
+                errors.addMessage(
+                    "Generated default method %s with parameters %s is"
+                        + " signature-compatible with more than one non-default method."
+                        + " Unable to create factory. As a workaround, remove the override"
+                        + " so javac stops generating a default method.",
                     defaultMethod, Arrays.asList(defaultMethod.getParameterTypes()));
               } else {
                 assistDataBuilder.put(defaultMethod, dataSoFar.get(otherMethod));
@@ -355,7 +393,7 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       }
 
       // If we generated any errors (from finding matching constructors, for instance), throw an exception.
-      if(errors.hasErrors()) {
+      if (errors.hasErrors()) {
         throw errors.toException();
       }
 
@@ -391,34 +429,39 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     return true;
   }
 
+  @Override
   public F get() {
     return factory;
   }
 
+  @Override
   public Set<Dependency<?>> getDependencies() {
-    Set<Dependency<?>> combinedDeps = new HashSet<Dependency<?>>();
-    for(AssistData data : assistDataByMethod.values()) {
+    Set<Dependency<?>> combinedDeps = new HashSet<>();
+    for (AssistData data : assistDataByMethod.values()) {
       combinedDeps.addAll(data.dependencies);
     }
     return ImmutableSet.copyOf(combinedDeps);
   }
-  
+
+  @Override
   public Key<F> getKey() {
     return factoryKey;
   }
 
   // Safe cast because values are typed to AssistedData, which is an AssistedMethod, and
   // the collection is immutable.
+  @Override
   @SuppressWarnings("unchecked")
   public Collection<AssistedMethod> getAssistedMethods() {
     return (Collection<AssistedMethod>) (Collection<?>) assistDataByMethod.values();
   }
 
+  @Override
   @SuppressWarnings("unchecked")
-  public <T, V> V acceptExtensionVisitor(BindingTargetVisitor<T, V> visitor,
-      ProviderInstanceBinding<? extends T> binding) {
+  public <T, V> V acceptExtensionVisitor(
+      BindingTargetVisitor<T, V> visitor, ProviderInstanceBinding<? extends T> binding) {
     if (visitor instanceof AssistedInjectTargetVisitor) {
-      return ((AssistedInjectTargetVisitor<T, V>)visitor).visit((AssistedInjectBinding<T>)this);
+      return ((AssistedInjectTargetVisitor<T, V>) visitor).visit((AssistedInjectBinding<T>) this);
     }
     return visitor.visit(binding);
   }
@@ -426,9 +469,10 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   private void validateFactoryReturnType(Errors errors, Class<?> returnType, Class<?> factoryType) {
     if (Modifier.isPublic(factoryType.getModifiers())
         && !Modifier.isPublic(returnType.getModifiers())) {
-      errors.addMessage("%s is public, but has a method that returns a non-public type: %s. "
-          + "Due to limitations with java.lang.reflect.Proxy, this is not allowed. "
-          + "Please either make the factory non-public or the return type public.",
+      errors.addMessage(
+          "%s is public, but has a method that returns a non-public type: %s. "
+              + "Due to limitations with java.lang.reflect.Proxy, this is not allowed. "
+              + "Please either make the factory non-public or the return type public.",
           factoryType, returnType);
     }
   }
@@ -440,8 +484,8 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   private boolean isTypeNotSpecified(TypeLiteral<?> typeLiteral, ConfigurationException ce) {
     Collection<Message> messages = ce.getErrorMessages();
     if (messages.size() == 1) {
-      Message msg = Iterables.getOnlyElement(
-          new Errors().keyNotFullySpecified(typeLiteral).getMessages());
+      Message msg =
+          Iterables.getOnlyElement(new Errors().keyNotFullySpecified(typeLiteral).getMessages());
       return msg.getMessage().equals(Iterables.getOnlyElement(messages).getMessage());
     } else {
       return false;
@@ -449,17 +493,17 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   }
 
   /**
-   * Finds a constructor suitable for the method.  If the implementation contained any constructors
+   * Finds a constructor suitable for the method. If the implementation contained any constructors
    * marked with {@link AssistedInject}, this requires all {@link Assisted} parameters to exactly
-   * match the parameters (in any order) listed in the method.  Otherwise, if no
-   * {@link AssistedInject} constructors exist, this will default to looking for an
-   * {@literal @}{@link Inject} constructor.
+   * match the parameters (in any order) listed in the method. Otherwise, if no {@link
+   * AssistedInject} constructors exist, this will default to looking for an {@literal @}{@link
+   * Inject} constructor.
    */
   private <T> InjectionPoint findMatchingConstructorInjectionPoint(
       Method method, Key<?> returnType, TypeLiteral<T> implementation, List<Key<?>> paramList)
       throws ErrorsException {
     Errors errors = new Errors(method);
-    if(returnType.getTypeLiteral().equals(implementation)) {
+    if (returnType.getTypeLiteral().equals(implementation)) {
       errors = errors.withSource(implementation);
     } else {
       errors = errors.withSource(returnType).withSource(implementation);
@@ -489,12 +533,11 @@ final class FactoryProvider2 <F> implements InvocationHandler,
         anyAssistedInjectConstructors = true;
         if (constructorHasMatchingParams(implementation, constructor, paramList, errors)) {
           if (matchingConstructor != null) {
-            errors
-                .addMessage(
-                    "%s has more than one constructor annotated with @AssistedInject"
-                        + " that matches the parameters in method %s.  Unable to create "
-                        + "AssistedInject factory.",
-                    implementation, method);
+            errors.addMessage(
+                "%s has more than one constructor annotated with @AssistedInject"
+                    + " that matches the parameters in method %s.  Unable to create "
+                    + "AssistedInject factory.",
+                implementation, method);
             throw errors.toException();
           } else {
             matchingConstructor = constructor;
@@ -503,26 +546,27 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       }
     }
 
-    if(!anyAssistedInjectConstructors) {
+    if (!anyAssistedInjectConstructors) {
       // If none existed, use @Inject.
       try {
         return InjectionPoint.forConstructorOf(implementation);
-      } catch(ConfigurationException e) {
+      } catch (ConfigurationException e) {
         errors.merge(e.getErrorMessages());
         throw errors.toException();
       }
     } else {
       // Otherwise, use it or fail with a good error message.
-      if(matchingConstructor != null) {
-          // safe because we got the constructor from this implementation.
-          @SuppressWarnings("unchecked")
-          InjectionPoint ip = InjectionPoint.forConstructor(
-              (Constructor<? super T>) matchingConstructor, implementation);
-          return ip;
+      if (matchingConstructor != null) {
+        // safe because we got the constructor from this implementation.
+        @SuppressWarnings("unchecked")
+        InjectionPoint ip =
+            InjectionPoint.forConstructor(
+                (Constructor<? super T>) matchingConstructor, implementation);
+        return ip;
       } else {
         errors.addMessage(
             "%s has @AssistedInject constructors, but none of them match the"
-            + " parameters in method %s.  Unable to create AssistedInject factory.",
+                + " parameters in method %s.  Unable to create AssistedInject factory.",
             implementation, method);
         throw errors.toException();
       }
@@ -530,21 +574,19 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   }
 
   /**
-   * Matching logic for constructors annotated with AssistedInject.
-   * This returns true if and only if all @Assisted parameters in the
-   * constructor exactly match (in any order) all @Assisted parameters
-   * the method's parameter.
+   * Matching logic for constructors annotated with AssistedInject. This returns true if and only if
+   * all @Assisted parameters in the constructor exactly match (in any order) all @Assisted
+   * parameters the method's parameter.
    */
-  private boolean constructorHasMatchingParams(TypeLiteral<?> type,
-      Constructor<?> constructor, List<Key<?>> paramList, Errors errors)
+  private boolean constructorHasMatchingParams(
+      TypeLiteral<?> type, Constructor<?> constructor, List<Key<?>> paramList, Errors errors)
       throws ErrorsException {
     List<TypeLiteral<?>> params = type.getParameterTypes(constructor);
     Annotation[][] paramAnnotations = constructor.getParameterAnnotations();
     int p = 0;
     List<Key<?>> constructorKeys = Lists.newArrayList();
     for (TypeLiteral<?> param : params) {
-      Key<?> paramKey = Annotations.getKey(param, constructor, paramAnnotations[p++],
-          errors);
+      Key<?> paramKey = Annotations.getKey(param, constructor, paramAnnotations[p++], errors);
       constructorKeys.add(paramKey);
     }
     // Require that every key exist in the constructor to match up exactly.
@@ -565,7 +607,8 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   }
 
   /** Calculates all dependencies required by the implementation and constructor. */
-  private Set<Dependency<?>> getDependencies(InjectionPoint ctorPoint, TypeLiteral<?> implementation) {
+  private Set<Dependency<?>> getDependencies(
+      InjectionPoint ctorPoint, TypeLiteral<?> implementation) {
     ImmutableSet.Builder<Dependency<?>> builder = ImmutableSet.builder();
     builder.addAll(ctorPoint.getDependencies());
     if (!implementation.getRawType().isInterface()) {
@@ -579,7 +622,7 @@ final class FactoryProvider2 <F> implements InvocationHandler,
   /** Return all non-assisted dependencies. */
   private Set<Dependency<?>> removeAssistedDeps(Set<Dependency<?>> deps) {
     ImmutableSet.Builder<Dependency<?>> builder = ImmutableSet.builder();
-    for(Dependency<?> dep : deps) {
+    for (Dependency<?> dep : deps) {
       Class<?> annotationType = dep.getKey().getAnnotationType();
       if (annotationType == null || !annotationType.equals(Assisted.class)) {
         builder.add(dep);
@@ -594,8 +637,8 @@ final class FactoryProvider2 <F> implements InvocationHandler,
    * the assisted bindings are immediately provided. This looks for hints that the values may be
    * lazily retrieved, by looking for injections of Injector or a Provider for the assisted values.
    */
-  private boolean isValidForOptimizedAssistedInject(Set<Dependency<?>> dependencies,
-      Class<?> implementation, TypeLiteral<?> factoryType) {
+  private boolean isValidForOptimizedAssistedInject(
+      Set<Dependency<?>> dependencies, Class<?> implementation, TypeLiteral<?> factoryType) {
     Set<Dependency<?>> badDeps = null; // optimization: create lazily
     for (Dependency<?> dep : dependencies) {
       if (isInjectorOrAssistedProvider(dep)) {
@@ -606,37 +649,47 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       }
     }
     if (badDeps != null && !badDeps.isEmpty()) {
-      logger.log(Level.WARNING, "AssistedInject factory {0} will be slow "
-          + "because {1} has assisted Provider dependencies or injects the Injector. "
-          + "Stop injecting @Assisted Provider<T> (instead use @Assisted T) "
-          + "or Injector to speed things up. (It will be a ~6500% speed bump!)  "
-          + "The exact offending deps are: {2}",
-          new Object[] {factoryType, implementation, badDeps} );
+      logger.log(
+          Level.WARNING,
+          "AssistedInject factory {0} will be slow "
+              + "because {1} has assisted Provider dependencies or injects the Injector. "
+              + "Stop injecting @Assisted Provider<T> (instead use @Assisted T) "
+              + "or Injector to speed things up. (It will be a ~6500% speed bump!)  "
+              + "The exact offending deps are: {2}",
+          new Object[] {factoryType, implementation, badDeps});
       return false;
     }
     return true;
   }
 
   /**
-   * Returns true if the dependency is for {@link Injector} or if the dependency
-   * is a {@link Provider} for a parameter that is {@literal @}{@link Assisted}.
+   * Returns true if the dependency is for {@link Injector} or if the dependency is a {@link
+   * Provider} for a parameter that is {@literal @}{@link Assisted}.
    */
   private boolean isInjectorOrAssistedProvider(Dependency<?> dependency) {
     Class<?> annotationType = dependency.getKey().getAnnotationType();
     if (annotationType != null && annotationType.equals(Assisted.class)) { // If it's assisted..
-      if (dependency.getKey().getTypeLiteral().getRawType().equals(Provider.class)) { // And a Provider...
+      if (dependency
+          .getKey()
+          .getTypeLiteral()
+          .getRawType()
+          .equals(Provider.class)) { // And a Provider...
         return true;
       }
-    } else if (dependency.getKey().getTypeLiteral().getRawType().equals(Injector.class)) { // If it's the Injector...
+    } else if (dependency
+        .getKey()
+        .getTypeLiteral()
+        .getRawType()
+        .equals(Injector.class)) { // If it's the Injector...
       return true;
     }
     return false;
   }
 
   /**
-   * Returns a key similar to {@code key}, but with an {@literal @}Assisted binding annotation.
-   * This fails if another binding annotation is clobbered in the process. If the key already has
-   * the {@literal @}Assisted annotation, it is returned as-is to preserve any String value.
+   * Returns a key similar to {@code key}, but with an {@literal @}Assisted binding annotation. This
+   * fails if another binding annotation is clobbered in the process. If the key already has the
+   * {@literal @}Assisted annotation, it is returned as-is to preserve any String value.
    */
   private <T> Key<T> assistKey(Method method, Key<T> key, Errors errors) throws ErrorsException {
     if (key.getAnnotationType() == null) {
@@ -644,22 +697,28 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     } else if (key.getAnnotationType() == Assisted.class) {
       return key;
     } else {
-      errors.withSource(method).addMessage(
-          "Only @Assisted is allowed for factory parameters, but found @%s",
-          key.getAnnotationType());
+      errors
+          .withSource(method)
+          .addMessage(
+              "Only @Assisted is allowed for factory parameters, but found @%s",
+              key.getAnnotationType());
       throw errors.toException();
     }
   }
 
   /**
-   * At injector-creation time, we initialize the invocation handler. At this time we make sure
-   * all factory methods will be able to build the target types.
+   * At injector-creation time, we initialize the invocation handler. At this time we make sure all
+   * factory methods will be able to build the target types.
    */
-  @Inject @Toolable
+  @Inject
+  @Toolable
   void initialize(Injector injector) {
     if (this.injector != null) {
-      throw new ConfigurationException(ImmutableList.of(new Message(FactoryProvider2.class,
-          "Factories.create() factories may only be used in one Injector!")));
+      throw new ConfigurationException(
+          ImmutableList.of(
+              new Message(
+                  FactoryProvider2.class,
+                  "Factories.create() factories may only be used in one Injector!")));
     }
 
     this.injector = injector;
@@ -668,13 +727,14 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       Method method = entry.getKey();
       AssistData data = entry.getValue();
       Object[] args;
-      if(!data.optimized) {
+      if (!data.optimized) {
         args = new Object[method.getParameterTypes().length];
         Arrays.fill(args, "dummy object for validating Factories");
       } else {
         args = null; // won't be used -- instead will bind to data.providers.
       }
-      getBindingFromNewInjector(method, args, data); // throws if the binding isn't properly configured
+      getBindingFromNewInjector(
+          method, args, data); // throws if the binding isn't properly configured
     }
   }
 
@@ -683,7 +743,8 @@ final class FactoryProvider2 <F> implements InvocationHandler,
    */
   public Binding<?> getBindingFromNewInjector(
       final Method method, final Object[] args, final AssistData data) {
-    checkState(injector != null,
+    checkState(
+        injector != null,
         "Factories.create() factories cannot be used until they're initialized by Guice.");
 
     final Key<?> returnType = data.returnType;
@@ -691,42 +752,46 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     // We ignore any pre-existing binding annotation.
     final Key<?> returnKey = Key.get(returnType.getTypeLiteral(), RETURN_ANNOTATION);
 
-    Module assistedModule = new AbstractModule() {
-      @Override
-      @SuppressWarnings({
-        "unchecked", "rawtypes"}) // raw keys are necessary for the args array and return value
-      protected void configure() {
-        Binder binder = binder().withSource(method);
+    Module assistedModule =
+        new AbstractModule() {
+          @Override
+          @SuppressWarnings({
+            "unchecked",
+            "rawtypes"
+          }) // raw keys are necessary for the args array and return value
+          protected void configure() {
+            Binder binder = binder().withSource(method);
 
-        int p = 0;
-        if(!data.optimized) {
-          for (Key<?> paramKey : data.paramTypes) {
-            // Wrap in a Provider to cover null, and to prevent Guice from injecting the parameter
-            binder.bind((Key) paramKey).toProvider(Providers.of(args[p++]));
-          }
-        } else {
-          for (Key<?> paramKey : data.paramTypes) {
-            // Bind to our ThreadLocalProviders.
-            binder.bind((Key) paramKey).toProvider(data.providers.get(p++));
-          }
-        }
+            int p = 0;
+            if (!data.optimized) {
+              for (Key<?> paramKey : data.paramTypes) {
+                // Wrap in a Provider to cover null, and to prevent Guice from injecting the parameter
+                binder.bind((Key) paramKey).toProvider(Providers.of(args[p++]));
+              }
+            } else {
+              for (Key<?> paramKey : data.paramTypes) {
+                // Bind to our ThreadLocalProviders.
+                binder.bind((Key) paramKey).toProvider(data.providers.get(p++));
+              }
+            }
 
-        Constructor constructor = data.constructor;
-        // Constructor *should* always be non-null here,
-        // but if it isn't, we'll end up throwing a fairly good error
-        // message for the user.
-        if(constructor != null) {
-          binder.bind(returnKey)
-              .toConstructor(constructor, (TypeLiteral)data.implementationType)
-              .in(Scopes.NO_SCOPE); // make sure we erase any scope on the implementation type
-        }
-      }
-    };
+            Constructor constructor = data.constructor;
+            // Constructor *should* always be non-null here,
+            // but if it isn't, we'll end up throwing a fairly good error
+            // message for the user.
+            if (constructor != null) {
+              binder
+                  .bind(returnKey)
+                  .toConstructor(constructor, (TypeLiteral) data.implementationType)
+                  .in(Scopes.NO_SCOPE); // make sure we erase any scope on the implementation type
+            }
+          }
+        };
 
     Injector forCreate = injector.createChildInjector(assistedModule);
     Binding<?> binding = forCreate.getBinding(returnKey);
     // If we have providers cached in data, cache the binding for future optimizations.
-    if(data.optimized) {
+    if (data.optimized) {
       data.cachedBinding = binding;
     }
     return binding;
@@ -736,6 +801,7 @@ final class FactoryProvider2 <F> implements InvocationHandler,
    * When a factory method is invoked, we create a child injector that binds all parameters, then
    * use that to get an instance of the return type.
    */
+  @Override
   public Object invoke(Object proxy, final Method method, final Object[] args) throws Throwable {
     // If we setup a method handle earlier for this method, call it.
     // This is necessary for default methods that java8 creates, so we
@@ -757,14 +823,14 @@ final class FactoryProvider2 <F> implements InvocationHandler,
     AssistData data = assistDataByMethod.get(method);
     checkState(data != null, "No data for method: %s", method);
     Provider<?> provider;
-    if(data.cachedBinding != null) { // Try to get optimized form...
+    if (data.cachedBinding != null) { // Try to get optimized form...
       provider = data.cachedBinding.getProvider();
     } else {
       provider = getBindingFromNewInjector(method, args, data).getProvider();
     }
     try {
       int p = 0;
-      for(ThreadLocalProvider tlp : data.providers) {
+      for (ThreadLocalProvider tlp : data.providers) {
         tlp.set(args[p++]);
       }
       return provider.get();
@@ -779,22 +845,24 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       }
       throw e;
     } finally {
-      for(ThreadLocalProvider tlp : data.providers) {
+      for (ThreadLocalProvider tlp : data.providers) {
         tlp.remove();
       }
     }
   }
 
-  @Override public String toString() {
+  @Override
+  public String toString() {
     return factory.getClass().getInterfaces()[0].getName();
   }
-  
+
   @Override
   public int hashCode() {
     return Objects.hashCode(factoryKey, collector);
   }
 
-  @Override public boolean equals(Object obj) {
+  @Override
+  public boolean equals(Object obj) {
     if (!(obj instanceof FactoryProvider2)) {
       return false;
     }
@@ -829,11 +897,9 @@ final class FactoryProvider2 <F> implements InvocationHandler,
 
   /** Wrapper around MethodHandles/MethodHandle, so we can compile+run on java6. */
   private static class MethodHandleWrapper {
-    static final int ALL_MODES = Modifier.PRIVATE
-        | Modifier.STATIC /* package */
-        | Modifier.PUBLIC
-        | Modifier.PROTECTED;
-    
+    static final int ALL_MODES =
+        Modifier.PRIVATE | Modifier.STATIC /* package */ | Modifier.PUBLIC | Modifier.PROTECTED;
+
     static final Method unreflectSpecial;
     static final Method bindTo;
     static final Method invokeWithArguments;
@@ -902,7 +968,8 @@ final class FactoryProvider2 <F> implements InvocationHandler,
       return invokeWithArguments.invoke(handle, (Object) args);
     }
 
-    @Override public String toString() {
+    @Override
+    public String toString() {
       return handle.toString();
     }
   }
