@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2006 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,12 +21,11 @@ import com.google.inject.Inject;
 import com.google.inject.Key;
 import com.google.inject.OutOfScopeException;
 import com.google.inject.internal.Errors;
-
 import java.io.IOException;
 import java.lang.ref.WeakReference;
-import java.util.concurrent.Callable;
+import java.util.concurrent.locks.Lock;
+import java.util.concurrent.locks.ReentrantLock;
 import java.util.logging.Logger;
-
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;
@@ -38,11 +37,11 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 /**
- * <p>
  * Apply this filter in web.xml above all other filters (typically), to all requests where you plan
- *  to use servlet scopes. This is also needed in order to dispatch requests to injectable filters
- *  and servlets:
- *  <pre>
+ * to use servlet scopes. This is also needed in order to dispatch requests to injectable filters
+ * and servlets:
+ *
+ * <pre>
  *  &lt;filter&gt;
  *    &lt;filter-name&gt;guiceFilter&lt;/filter-name&gt;
  *    &lt;filter-class&gt;<b>com.google.inject.servlet.GuiceFilter</b>&lt;/filter-class&gt;
@@ -54,20 +53,18 @@ import javax.servlet.http.HttpServletResponse;
  *  &lt;/filter-mapping&gt;
  *  </pre>
  *
- * This filter must appear before every filter that makes use of Guice injection or servlet
- * scopes functionality. Typically, you will only register this filter in web.xml and register
- * any other filters (and servlets) using a {@link ServletModule}.
+ * This filter must appear before every filter that makes use of Guice injection or servlet scopes
+ * functionality. Typically, you will only register this filter in web.xml and register any other
+ * filters (and servlets) using a {@link ServletModule}.
  *
  * @author crazybob@google.com (Bob Lee)
  * @author dhanji@gmail.com (Dhanji R. Prasanna)
  */
 public class GuiceFilter implements Filter {
-  static final ThreadLocal<Context> localContext = new ThreadLocal<Context>();
+  static final ThreadLocal<Context> localContext = new ThreadLocal<>();
   static volatile FilterPipeline pipeline = new DefaultFilterPipeline();
 
-  /**
-   * We allow both the static and dynamic versions of the pipeline to exist.
-   */
+  /** We allow both the static and dynamic versions of the pipeline to exist. */
   private final FilterPipeline injectedPipeline;
 
   /** Used to inject the servlets configured via {@link ServletModule} */
@@ -76,12 +73,13 @@ public class GuiceFilter implements Filter {
 
   private static final String MULTIPLE_INJECTORS_WARNING =
       "Multiple Servlet injectors detected. This is a warning "
-      + "indicating that you have more than one "
-      + GuiceFilter.class.getSimpleName() + " running "
-      + "in your web application. If this is deliberate, you may safely "
-      + "ignore this message. If this is NOT deliberate however, "
-      + "your application may not work as expected.";
-  
+          + "indicating that you have more than one "
+          + GuiceFilter.class.getSimpleName()
+          + " running "
+          + "in your web application. If this is deliberate, you may safely "
+          + "ignore this message. If this is NOT deliberate however, "
+          + "your application may not work as expected.";
+
   private static final Logger LOGGER = Logger.getLogger(GuiceFilter.class.getName());
 
   public GuiceFilter() {
@@ -89,7 +87,8 @@ public class GuiceFilter implements Filter {
     this(null);
   }
 
-  @Inject protected GuiceFilter(FilterPipeline filterPipeline) {
+  @Inject
+  protected GuiceFilter(FilterPipeline filterPipeline) {
     injectedPipeline = filterPipeline;
   }
 
@@ -113,6 +112,7 @@ public class GuiceFilter implements Filter {
     localContext.remove();
   }
 
+  @Override
   public void doFilter(
       final ServletRequest servletRequest,
       final ServletResponse servletResponse,
@@ -124,16 +124,16 @@ public class GuiceFilter implements Filter {
     Context previous = GuiceFilter.localContext.get();
     HttpServletRequest request = (HttpServletRequest) servletRequest;
     HttpServletResponse response = (HttpServletResponse) servletResponse;
-    HttpServletRequest originalRequest
-        = (previous != null) ? previous.getOriginalRequest() : request;
+    HttpServletRequest originalRequest =
+        (previous != null) ? previous.getOriginalRequest() : request;
     try {
-      new Context(originalRequest, request, response).call(new Callable<Void>() {
-        @Override public Void call() throws Exception {
-          //dispatch across the servlet pipeline, ensuring web.xml's filterchain is honored
-          filterPipeline.dispatch(servletRequest, servletResponse, filterChain);
-          return null;
-        }
-      });
+      RequestScoper.CloseableScope scope = new Context(originalRequest, request, response).open();
+      try {
+        //dispatch across the servlet pipeline, ensuring web.xml's filterchain is honored
+        filterPipeline.dispatch(servletRequest, servletResponse, filterChain);
+      } finally {
+        scope.close();
+      }
     } catch (IOException e) {
       throw e;
     } catch (ServletException e) {
@@ -162,20 +162,29 @@ public class GuiceFilter implements Filter {
   private static Context getContext(Key<?> key) {
     Context context = localContext.get();
     if (context == null) {
-      throw new OutOfScopeException("Cannot access scoped [" + Errors.convert(key) 
-          + "]. Either we are not currently inside an HTTP Servlet request, or you may"
-          + " have forgotten to apply " + GuiceFilter.class.getName()
-          + " as a servlet filter for this request.");
+      throw new OutOfScopeException(
+          "Cannot access scoped ["
+              + Errors.convert(key)
+              + "]. Either we are not currently inside an HTTP Servlet request, or you may"
+              + " have forgotten to apply "
+              + GuiceFilter.class.getName()
+              + " as a servlet filter for this request.");
     }
     return context;
   }
 
-  static class Context {
+  static class Context implements RequestScoper {
     final HttpServletRequest originalRequest;
     final HttpServletRequest request;
     final HttpServletResponse response;
 
-    Context(HttpServletRequest originalRequest, HttpServletRequest request,
+    // Synchronized to prevent two threads from using the same request
+    // scope concurrently.
+    final Lock lock = new ReentrantLock();
+
+    Context(
+        HttpServletRequest originalRequest,
+        HttpServletRequest request,
         HttpServletResponse response) {
       this.originalRequest = originalRequest;
       this.request = request;
@@ -194,24 +203,27 @@ public class GuiceFilter implements Filter {
       return response;
     }
 
-    // Synchronized to prevent two threads from using the same request
-    // scope concurrently.
-    synchronized <T> T call(Callable<T> callable) throws Exception {
-      Context previous = localContext.get();
+    @Override
+    public CloseableScope open() {
+      lock.lock();
+      final Context previous = localContext.get();
       localContext.set(this);
-      try {
-        return callable.call();
-      } finally {
-        localContext.set(previous);
-      }
+      return new CloseableScope() {
+        @Override
+        public void close() {
+          localContext.set(previous);
+          lock.unlock();
+        }
+      };
     }
   }
 
+  @Override
   public void init(FilterConfig filterConfig) throws ServletException {
     final ServletContext servletContext = filterConfig.getServletContext();
 
     // Store servlet context in a weakreference, for injection
-    GuiceFilter.servletContext = new WeakReference<ServletContext>(servletContext);
+    GuiceFilter.servletContext = new WeakReference<>(servletContext);
 
     // In the default pipeline, this is a noop. However, if replaced
     // by a managed pipeline, a lazy init will be triggered the first time
@@ -220,6 +232,7 @@ public class GuiceFilter implements Filter {
     filterPipeline.initPipeline(servletContext);
   }
 
+  @Override
   public void destroy() {
 
     try {
